==> kari-0.23.tar.gz: kari-0.23/neve/neve.h <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __NEVE_H__
#define __NEVE_H__

#include <gtk/gtkwidget.h>

#include "common.h"

/* The types of neve nodes the parser will generate */

typedef enum _neve_types neve_types;
enum _neve_types
  {
    text = 1, image, horizontal_rule, line_break, paragraph_break, 
    title, end_link, start_list_element, undefined
  };

/* The numbering type for ordered lists (<OL>) */

typedef enum _numbering_type numbering_type;
enum _numbering_type
  {
    arabic = 1, lalpha, ualpha, lroman, uroman
  };

/* The bullet type for list elements in unordered lists (<UL>)*/

typedef enum _bullet_type bullet_type;
enum _bullet_type
  {
    disc = 1, square, circle
  };

/* The aligment.  This is overloaded. the first 4 only apply to text,
 * where as the last 3 only apply to images.  
 *
 * I'm not convinced this overloading is a good idea, and it should be
 * revisited in the future.  (FIXME)
 *
 * justify is a 3.0 tag which was dropped from 3.2 and 4.0, either
 * because Netscape and MS were unwilling to implement it, or because
 * it's not a HTML issue, but something that should be done in
 * CSS1/DSSSL, depending on one's perspective. */

typedef enum _neve_alignment neve_alignment;
enum _neve_alignment
  {
    left = 1, centre, right, justify, top, middle, bottom
  };

/* Colours as passed by the parser.  Astute observers will notice a
 * startling similarity to GdkColor.  GdkColor wasn't used to retain
 * the parser's widget independence. */
typedef struct _colour_type colour_type;
struct _colour_type
  {
    int red;
    int green;
    int blue;
  };

/* Logical attributes of each neve node */
typedef struct _logical_attribute_types logical_attribute_types;
struct _logical_attribute_types
  {
    int header_level;
    boolean link;
    boolean link_visited;	/* Shouldn't really be an int, but some type */
    boolean pre_text;
    boolean ul_list_element;
    bullet_type ul_bullet_type;
    numbering_type ol_number_type;
    boolean ol_list_element;
    boolean dl_list_element;
    int list_indent_level;
    int item_number;
    char *item_num_text;
    boolean blockquote;
  };

/* Physical attributes of each neve node */
typedef struct _physical_attribute_types physical_attribute_types;
struct _physical_attribute_types
  {
    int font_size;
    boolean strong;
    boolean emphasis;
    boolean code;
    boolean blockquote;
    neve_alignment alignment;	/* 3.0+ */
    boolean underline;		/* 3.0+ */
    boolean subscript;		/* 3.0+ */
    boolean superscript;	/* 3.0+ */
    boolean strike;		/* 3.2+ */
    int width;
    int height;
    colour_type font_colour;	/* 3.2+ */
  };

/* Neve.  This is the primary data structure used to store the
 * parsed HTML.  */
typedef struct _neve_in_chains neve_in_chains;
struct _neve_in_chains
  {
    char *buf;
    char *href;
    char *src;
    neve_types type;
    physical_attribute_types physical_attributes;
    logical_attribute_types logical_attributes;
    neve_in_chains *previous;
    neve_in_chains *next;
  };

/* Louise - the line cache structure.  We need this so we can jump to
 * any point in the document, without re-rendering from the top. */
typedef struct _louise louise;
struct _louise
  {
    neve_in_chains *start_of_line;
    int offset_into_first_neve;	/* Offset into buf or Y offset into an
                                   image */
    int line_number;
    int max_font_height;        /* Greatest font height */ /* FIXME: will break with different decents */
    int y_coordinate;		/* Running depth into the page; needed
                                   because of variable heights of
                                   fonts on a line */
    louise *previous;
    louise *next;
  };

/* Charisma is the linked list of links on a page.  When we receive a
 * mouse click we traverse down a charisma looking for a match. */
typedef struct _charisma charisma;
struct _charisma
  {
    char *href;
    GdkRectangle *area;
    charisma *next;
  };

/* These return values are used by both the neve2louise converter and
 * the render, so are declared publicly here. */
typedef enum _louise_parse_neve_return_type louise_parse_neve_return_type;
enum _louise_parse_neve_return_type
  {
    exhausted_node = 1, hit_end_of_line,
    skip_to_next_line, skip_to_next_paragraph
  };


#include "lisa.h"

void lisa_take_neve (neve_in_chains * neve, GtkLisa * lisa);
void neve_to_louise (neve_in_chains * neve, GtkLisa * lisa);

#endif /* __NEVE_H__ */

==> kari-0.30.tar.gz: kari-0.30/neve/neve.h <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __NEVE_H__
#define __NEVE_H__

#include <gtk/gtkwidget.h>

#include "common.h"

/* The types of neve nodes the parser will generate */

typedef enum _neve_types neve_types;
enum _neve_types
  {
    text = 1, image, horizontal_rule, line_break, paragraph_break, 
    end_link, start_list_element
  };

/* The numbering type for ordered lists (<OL>) */

typedef enum _numbering_type numbering_type;
enum _numbering_type
  {
    arabic = 1, lalpha, ualpha, lroman, uroman
  };

/* The bullet type for list elements in unordered lists (<UL>)*/

typedef enum _bullet_type bullet_type;
enum _bullet_type
  {
    disc = 1, square, circle
  };

/* The aligment.  This is overloaded. the first 4 only apply to text,
 * where as the last 3 only apply to images.  
 *
 * I'm not convinced this overloading is a good idea, and it should be
 * revisited in the future.  (FIXME)
 *
 * justify is a 3.0 tag which was dropped from 3.2 and 4.0, either
 * because Netscape and MS were unwilling to implement it, or because
 * it's not a HTML issue, but something that should be done in
 * CSS1/DSSSL, depending on one's perspective. */

typedef enum _neve_alignment neve_alignment;
enum _neve_alignment
  {
    left = 1, centre, right, justify, top, middle, bottom
  };

/* Colours as passed by the parser.  Astute observers will notice a
 * startling similarity to GdkColor.  GdkColor wasn't used to retain
 * the parser's widget independence. */
typedef struct _colour_type colour_type;
struct _colour_type
  {
    int red;
    int green;
    int blue;
  };

/* Logical attributes of each neve node */
typedef struct _logical_attribute_types logical_attribute_types;
struct _logical_attribute_types
  {
    boolean link;
    boolean link_visited;	/* Shouldn't really be an int, but some type */
    boolean preformatted;
    boolean ul_list_element;
    bullet_type ul_bullet_type;
    numbering_type ol_number_type;
    boolean ol_list_element;
    boolean dl_list_element;
    int list_indent_level;
    int item_number;
    char *item_num_text;
    boolean blockquote;
  };

/* Physical attributes of each neve node */
typedef struct _physical_attribute_types physical_attribute_types;
struct _physical_attribute_types
  {
    int font_level; /* Used for <FONT> level changes and <h?> changes */
    boolean strong;
    boolean emphasis;
    boolean code;
    boolean blockquote;
    boolean monospace;
    neve_alignment alignment;	/* 3.0+ */
    boolean underline;		/* 3.0+ */
    boolean subscript;		/* 3.0+ */
    boolean superscript;	/* 3.0+ */
    boolean strike;		/* 3.2+ */
    int width;
    int height;
    colour_type draw_colour;	/* 3.2+ */
  };

/* Neve.  This is the primary data structure used to store the
 * parsed HTML.  */
typedef struct _neve_in_chains neve_in_chains;
struct _neve_in_chains
  {
    char *buf;
    char *href;
    char *src;
    neve_types type;
    physical_attribute_types physical_attributes;
    logical_attribute_types logical_attributes;
    neve_in_chains *previous;
    neve_in_chains *next;
  };

/* Louise - the line cache structure.  We need this so we can jump to
 * any point in the document, without re-rendering from the top. */
typedef struct _louise louise;
struct _louise
  {
    neve_in_chains *start_of_line;
    int offset_into_first_neve;	/* Offset into buf or Y offset into an
                                   image */
    int line_number;
    int max_font_height;        /* Greatest font height */ /* FIXME: will break with different decents */
    int y_coordinate;		/* Running depth into the page; needed
                                   because of variable heights of
                                   fonts on a line */
    louise *previous;
    louise *next;
  };

/* Charisma is the linked list of links on a page.  When we receive a
 * mouse click we traverse down a charisma looking for a match. */
typedef struct _charisma charisma;
struct _charisma
  {
    char *href;
    GdkRectangle *area;
    charisma *next;
  };

/* These return values are used by both the neve2louise converter and
 * the render, so are declared publicly here. */
typedef enum _louise_parse_neve_return_type louise_parse_neve_return_type;
enum _louise_parse_neve_return_type
  {
    exhausted_node = 1, hit_end_of_line,
    skip_to_next_line, skip_to_next_paragraph
  };


#include "smg.h"
#include "lisa.h"

void lisa_take_neve (neve_in_chains * neve, BrowserWindow *paula);
void neve_to_louise (neve_in_chains * neve, GtkLisa *lisa);

#endif /* __NEVE_H__ */
